@@ -23,7 +23,7 @@ Create Dragonfly ContextShade.
             schedule to be looked up in the schedule library. This can also be a
             custom schedule object. If no energy schedule is input here, the default
             will be always opaque.
-    
+
     Returns:
         report: Reports, errors, warnings, etc.
         context: Dragonfly ContextShades.
@@ -31,13 +31,18 @@ Create Dragonfly ContextShade.
 
 ghenv.Component.Name = 'DF ContextShade'
 ghenv.Component.NickName = 'Context'
-ghenv.Component.Message = '1.0.0'
+ghenv.Component.Message = '1.1.0'
 ghenv.Component.Category = 'Dragonfly'
 ghenv.Component.SubCategory = '0 :: Create'
 ghenv.Component.AdditionalHelpFromDocStrings = '7'
 
 import uuid
 
+try:  # import the core honeybee dependencies
+    from honeybee.typing import clean_and_id_string
+except ImportError as e:
+    raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))
+
 try:  # import the core dragonfly dependencies
     from dragonfly.context import ContextShade
 except ImportError as e:
@@ -45,53 +50,43 @@ except ImportError as e:
 
 try:  # import the ladybug_rhino dependencies
     from ladybug_rhino.togeometry import to_face3d
-    from ladybug_rhino.grasshopper import all_required_inputs
+    from ladybug_rhino.grasshopper import all_required_inputs, longest_list
 except ImportError as e:
     raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))
 
 try:  # import the honeybee-energy extension
-    from honeybee_energy.lib.constructions import shade_construction_by_name
-    from honeybee_energy.lib.schedules import schedule_by_name
+    from honeybee_energy.lib.constructions import shade_construction_by_identifier
+    from honeybee_energy.lib.schedules import schedule_by_identifier
 except ImportError as e:
-    if ep_constr_ is not None:
+    if len(ep_constr_) != 0:
         raise ValueError('ep_constr_ has been specified but honeybee-energy '
                          'has failed to import.\n{}'.format(e))
-    elif ep_trans_sch_ is not None:
+    elif len(ep_trans_sch_) != 0:
         raise ValueError('ep_trans_sch_ has been specified but honeybee-energy '
                          'has failed to import.\n{}'.format(e))
 
-try:  # import the dragonfly-energy extension
-    import dragonfly_energy
-except ImportError as e:
-    if ep_constr_ is not None:
-        raise ValueError('ep_constr_ has been specified but dragonfly-energy '
-                         'has failed to import.\n{}'.format(e))
-    elif ep_trans_sch_ is not None:
-        raise ValueError('ep_trans_sch_ has been specified but dragonfly-energy '
-                         'has failed to import.\n{}'.format(e))
-
 
 if all_required_inputs(ghenv.Component):
     context = []  # list of context shades that will be returned
-    
-    # set default name
-    name = _name_ if _name_ is not None else str(uuid.uuid4())
-    
-    # create the ContextShades
+    base_name = str(uuid.uuid4())
     for i, geo in enumerate(_geo):
         lb_faces = to_face3d(geo)
-        df_shd = ContextShade('{}_{}'.format(name, i), lb_faces)
-        
+        name = longest_list(_name_, i) if len(_name_) != 0 else base_name
+        df_shd = ContextShade(clean_and_id_string('{}_{}'.format(name, i)), lb_faces)
+        df_shd.display_name = '{}_{}'.format(name, i)
+
         # try to assign the energyplus construction
-        if ep_constr_ is not None:
-            if isinstance(ep_constr_, str):
-                ep_constr_ = shade_construction_by_name(ep_constr_)
-            df_shd.properties.energy.construction = ep_constr_
-        
+        if len(ep_constr_) != 0:
+            ep_constr = longest_list(ep_constr_, i)
+            if isinstance(ep_constr, str):
+                ep_constr = shade_construction_by_identifier(ep_constr)
+            df_shd.properties.energy.construction = ep_constr
+
         # try to assign the energyplus transmittance schedule
-        if ep_trans_sch_ is not None:
-            if isinstance(ep_trans_sch_, str):
-                ep_trans_sch_ = schedule_by_name(ep_trans_sch_)
-            df_shd.properties.energy.transmittance_schedule = ep_trans_sch_
-        
+        if len(ep_trans_sch_) != 0:
+            ep_trans_sch = longest_list(ep_trans_sch_, i)
+            if isinstance(ep_trans_sch, str):
+                ep_trans_sch = schedule_by_identifier(ep_trans_sch)
+            df_shd.properties.energy.transmittance_schedule = ep_trans_sch
+
         context.append(df_shd)  # collect the final ContextShades
\ No newline at end of file
